@@ -9,6 +9,6 @@ interface PromiseAdapterInterface
     public function promise();
     public function resolve();
     public function reject();
-    public function progress();
+    public function notify();
     public function settle();
 }
